@@ -3,7 +3,7 @@
    xsane-batch-scan.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2004 Oliver Rauch
+   Copyright (C) 1998-2005 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -505,10 +505,14 @@ static void xsane_batch_scan_scan_list(void)
 
     while (xsane.scanning)
     {
+#if 0
       if (gtk_events_pending())
       {
         gtk_main_iteration();
       }
+#elseif
+      gtk_main_iteration();
+#endif
     }
 
     if ( (xsane.status_of_last_scan != SANE_STATUS_GOOD) && (xsane.status_of_last_scan != SANE_STATUS_EOF) )
@@ -955,6 +959,7 @@ void xsane_create_batch_scan_dialog(const char *devicetext)
 
   xsane.batch_scan_dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   xsane_set_window_icon(xsane.batch_scan_dialog, 0);
+  gtk_window_add_accel_group(GTK_WINDOW(xsane.batch_scan_dialog), xsane.accelerator_group);
 
   snprintf(buf, sizeof(buf), "%s %s", WINDOW_BATCH_SCAN, devicetext);
   gtk_window_set_title(GTK_WINDOW(xsane.batch_scan_dialog), buf);
