@@ -3,7 +3,7 @@
    xsane-preferences.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2004 Oliver Rauch
+   Copyright (C) 1998-2005 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -80,6 +80,7 @@ Preferences preferences =
        0,               /* no default pop3 passsword */
        0,		/* no mail project */
        0,		/* no mail viewer */
+       0,		/* no mail filetype */
 #endif
        0,		/* no default ocrcommand */
        0,		/* no default ocr input file option */
@@ -184,6 +185,7 @@ desc[] =
     {"mail-pop3-pass",			xsane_rc_pref_string,	POFFSET(mail_pop3_pass)},
     {"mail-project",			xsane_rc_pref_string,	POFFSET(mail_project)},
     {"mail-viewer",			xsane_rc_pref_string,	POFFSET(mail_viewer)},
+    {"mail-filetype",			xsane_rc_pref_string,	POFFSET(mail_filetype)},
 #endif
     {"ocr-command",			xsane_rc_pref_string,	POFFSET(ocr_command)},
     {"ocr-inputfile-option",		xsane_rc_pref_string,	POFFSET(ocr_inputfile_option)},
@@ -394,28 +396,43 @@ void preferences_restore(int fd)
     if (w.status)
     {
       xsane_rc_io_w_exit(&w);
+      preferences.printerdefinitions = 0;
+      preferences.preset_area_definitions = 0;
      return;
     }
 
     xsane_rc_io_w_string(&w, &name);
-    if (w.status || !name)
+    if (w.status == EINVAL) /* not a string */
+    {
+      w.status = 0;
+      xsane_rc_io_w_skip_newline(&w); /* skip this line */
+    }
+    else if (w.status || !name) /* other error */
     {
       xsane_rc_io_w_exit(&w);
      return;
     }
-
-    for (i = 0; i < NELEMS (desc); ++i)
+    else /* identifier read */
     {
-      if (strcmp(name, desc[i].name) == 0)
+      for (i = 0; i < NELEMS(desc); ++i)
+      {
+        if (strcmp(name, desc[i].name) == 0)
+        {
+          DBG(DBG_info2, "reading preferences value for %s\n", desc[i].name);
+          (*desc[i].codec) (&w, &preferences, desc[i].offset);
+          break;
+        }
+      }
+
+      if (!strcmp(name, "printerdefinitions"))
       {
-        DBG(DBG_info2, "reading preferences value for %s\n", desc[i].name);
-        (*desc[i].codec) (&w, &preferences, desc[i].offset);
         break;
       }
-    }
-    if (!strcmp(name, "printerdefinitions"))
-    {
-      break;
+      else if (i == NELEMS(desc))
+      {
+        DBG(DBG_info2, "preferences identifier %s unknown\n", name);
+        xsane_rc_io_w_skip_newline(&w); /* skip this line */
+      }
     }
   }
 
