@@ -3,7 +3,7 @@
    xsane-text.h
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2004 Oliver Rauch
+   Copyright (C) 1998-2005 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -239,15 +239,7 @@
 #define TEXT_MAIL_TEXT			_("Email text:")
 #define TEXT_ATTACHMENTS		_("Attachments:")
 #define TEXT_MAIL_STATUS		_("Project status:")
-#define TEXT_MAIL_STATUS_NOT_CREATED		_("not created")
-#define TEXT_MAIL_STATUS_CREATED		_("created")
-#define TEXT_MAIL_STATUS_CHANGED		_("changed")
-#define TEXT_MAIL_STATUS_ERR_READ_PROJECT	_("error reading mailproject")
-#define TEXT_MAIL_STATUS_POP3_CONNECTION_FAILED	_("POP3 connection failed")
-#define TEXT_MAIL_STATUS_POP3_LOGIN_FAILED	_("POP3 login failed")
-#define TEXT_MAIL_STATUS_SMTP_CONNECTION_FAILED	_("SMTP connection failed")
-#define TEXT_MAIL_STATUS_SENT			_("sent")
-#define TEXT_MAIL_STATUS_SENDING		_("sending")
+#define TEXT_MAIL_FILETYPE		_("Mail image filetype:")
 
 #define TEXT_MEDIUM_DEFINITION_NAME	_("Medium Name:")
 
@@ -445,6 +437,7 @@
 #define DESC_MAILIMAGENAME		_("Enter new name for mail image")
 #define DESC_MAILRECEIVER		_("Enter email address")
 #define DESC_MAILSUBJECT		_("Enter subject of email")
+#define DESC_MAIL_FILETYPE		_("Select filetype for image attachments")
 #define DESC_PRESET_AREA_RENAME		_("Enter new name for preset area")
 #define DESC_PRESET_AREA_ADD		_("Enter name for new preset area")
 #define DESC_MEDIUM_RENAME		_("Enter new name for medium definition")
@@ -811,4 +804,22 @@ The format of [DEVICE] is backendname:devicefile (e.g. umax:/dev/scanner).\n\
 #define MENU_ITEM_MEDIUM_KONICA_NEG_VX_100	N_("Konica negative VX 100")
 #define MENU_ITEM_MEDIUM_ROSSMANN_NEG_HR_100	N_("Rossmann negative HR 100")
 
+#define TEXT_MAIL_STATUS_NOT_CREATED		N_("Mail project not created")
+#define TEXT_MAIL_STATUS_CREATED		N_("Mail project created")
+#define TEXT_MAIL_STATUS_CHANGED		N_("Mail project changed")
+#define TEXT_MAIL_STATUS_ERR_READ_PROJECT	N_("Error reading mailproject")
+#define TEXT_MAIL_STATUS_POP3_CONNECTION_FAILED	N_("POP3 connection failed")
+#define TEXT_MAIL_STATUS_POP3_LOGIN_FAILED	N_("POP3 login failed")
+#define TEXT_MAIL_STATUS_SMTP_CONNECTION_FAILED	N_("SMTP connection failed")
+#define TEXT_MAIL_STATUS_SMTP_ERR_FROM		N_("From entry not accepted")
+#define TEXT_MAIL_STATUS_SMTP_ERR_RCPT		N_("Receiver entry not accepted")
+#define TEXT_MAIL_STATUS_SMTP_ERR_DATA		N_("Mail data not accepted")
+#define TEXT_MAIL_STATUS_SENDING		N_("Sending mail")
+#define TEXT_MAIL_STATUS_SENT			N_("Mail has been sent")
+
+#define TEXT_FAX_STATUS_NOT_CREATED		N_("Fax project not created")
+#define TEXT_FAX_STATUS_CREATED			N_("Fax project created")
+#define TEXT_FAX_STATUS_CHANGED			N_("Fax project changed")
+#define TEXT_FAX_STATUS_QUEUEING_FAX		N_("Queueing Fax")
+#define TEXT_FAX_STATUS_FAX_QUEUED		N_("Fax is queued")
 #endif
